==> deepin-image-viewer_5.7.4.orig.tar.xz: deepin-image-viewer-5.7.4/src/translations/deepin-image-viewer_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Pelihat Imej</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pelihat Imej merupakan  sebuah alat pelihat imej dengan antara muka berfesyen dan prestasi yang lancar.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imej</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Maklumat asas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Fail ini mengandungi halaman berbilang, sila guna Evince untuk melihat semua halaman.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Buka Direktori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Anda tiada keizinan untuk melihat imej</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Fail imej tidak ditemui</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nama </translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tarikh diubah suai</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimensi</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Saiz fail</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Tarikh ditangkap</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mod dedahan</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program dedahan</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Masa dedahan</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Denyar</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Bukaan</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Panjang fokus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Bukaan maks</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mod pemeteran</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Imbangan putih</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Pemampasan denyar</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model kanta</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Ruangwarna</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensi</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Tiada penskalaan</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Suai muat halaman dengan imej</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Suai muat imej dengan halaman</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skala ke:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Sentimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inci</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Kedudukan Imej</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Penskalaan</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Tetapan Imej</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Tetapan Imej</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Bidaian</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Penukar</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Pelungsur</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Gelang</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Sahkan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Masukan satu nama baharu</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Pilih Direktori</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Direktori ini dilumpuhkan untuk penyegerakan</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Tambah folder</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Pengurusan Direktori Segerak</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Senarai direktori kosong</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Batal segerak</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imej</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Peranti telah ditanggalkan</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Direktori ini tiada lagi wujud</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Mengira...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pelihatan Imej</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Tamat paparan</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Skrin terdahulu</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Skrin berikutnya</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zum masuk</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zum keluar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Sila masukkan pintasan baharu</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Lihat Gambar</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Pulih Lalai</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Tamat paparan</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Main</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Tetapan Slaid</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Tukar kesan</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Jangkamasa</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Tukar jangkamasa</translation>
    </message>
    <message>
        <source>second</source>
        <translation>saat</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Kegemaran saya</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Saiz 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Suai muat dengan tetingkap</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Undur</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Pengurusan imej</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Kegemaran saya</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Saiz 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Suai muat dengan tetingkap</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Tiada fail imej ditemui</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Fail imej tidak ditemui</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Tetapan Slaid</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Kesan</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Jangkamasa</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Pintasan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Garis Masa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambah ke album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Tambah ke album baharu</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang dari album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Tunjuk tetingkap navigasi</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sembunyi tetingkap navigasi</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Semua imej</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_ms.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Fail imej tidak ditemui</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Buka Imej</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pelihatan Imej</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Keluar dari skrin penuh</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Ekstrak teks</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Paparan slaid</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetapkan sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Maklumat imej</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zum masuk</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zum keluar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Buka</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Pelihat Imej</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pelihat Imej merupakan  sebuah alat pelihat imej dengan antara muka berfesyen dan prestasi yang lancar.</translation>
    </message>
</context>
</TS>
